@@ -7,7 +7,7 @@ class MaybeRedirectView(object):
         
         if error_type == 'NotFound':
 
-            path = self.request.physicalPathFromURL(self.request.URL)
+            path = self.request.physicalPathFromURL(self.request.ACTUAL_URL)
             portal_path = self.context.portal_url.getPortalObject(
                 ).getPhysicalPath()
             rel_path = '/'.join(path[len(portal_path):])
